#################
ctrl_bps_htcondor
#################

.. image:: https://img.shields.io/pypi/v/lsst-ctrl-bps-htcondor.svg
    :target: https://pypi.org/project/lsst-ctrl-bps-htcondor/
.. image:: https://codecov.io/gh/lsst/ctrl_bps_htcondor/branch/main/graph/badge.svg?token=Cnl6kYKVWL
    :target: https://codecov.io/gh/lsst/ctrl_bps_htcondor

``ctrl_bps_htcondor`` is a package in the `LSST Science Pipelines <https://pipelines.lsst.io>`_.

It provides a HTCondor plugin for LSST PipelineTask execution framework, based on ``ctrl_bps``.

* SPIE paper from 2022: `The Vera C. Rubin Observatory Data Butler and Pipeline Execution System <https://arxiv.org/abs/2206.14941>`_.

PyPI: `lsst-ctrl-bps-htcondor <https://pypi.org/project/lsst-ctrl-bps-htcondor/>`_

This software is dual licensed under the GNU General Public License (version 3 of the License, or (at your option) any later version, and also under a 3-clause BSD license.
Recipients may choose which of these licenses to use; please see the files gpl-3.0.txt and/or bsd_license.txt, respectively.
